
# This file was generated by 'versioneer.py' (0.28) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2023-09-19T17:36:08+0200",
 "dirty": false,
 "error": null,
 "full-revisionid": "54c0cf862414617d35fe4864c3409e7e98d5e37b",
 "version": "0.58.0"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
